<?php
/**
 * Requirements
 *
 * @package GamiPress\Caldera_Forms\Requirements
 * @since 1.0.0
 */
// Exit if accessed directly
if( !defined( 'ABSPATH' ) ) exit;

/**
 * Add the form field to the requirement object
 *
 * @param $requirement
 * @param $requirement_id
 *
 * @return array
 */
function gamipress_cf_requirement_object( $requirement, $requirement_id ) {

    if( isset( $requirement['trigger_type'] )
        && $requirement['trigger_type'] === 'gamipress_cf_specific_new_form_submission' ) {

        // The post category field
        $requirement['caldera_form'] = get_post_meta( $requirement_id, '_gamipress_caldera_form', true );

    }

    return $requirement;
}
add_filter( 'gamipress_requirement_object', 'gamipress_cf_requirement_object', 10, 2 );

/**
 * Form field on requirements UI
 *
 * @param $requirement_id
 * @param $post_id
 */
function gamipress_cf_requirement_ui_fields( $requirement_id, $post_id ) {

    $forms = Caldera_Forms::get_forms();
    $selected = get_post_meta( $requirement_id, '_gamipress_caldera_form', true ); ?>

    <select class="select-caldera-form">
        <?php foreach( $forms as $form ) : ?>
            <option value="<?php echo $form['ID']; ?>" <?php selected( $selected, $form['ID'] ); ?>><?php echo $form['name']; ?></option>
        <?php endforeach; ?>
    </select>

    <?php
}
add_action( 'gamipress_requirement_ui_html_after_achievement_post', 'gamipress_cf_requirement_ui_fields', 10, 2 );

/**
 * Custom handler to save the form on requirements UI
 *
 * @param $requirement_id
 * @param $requirement
 */
function gamipress_cf_ajax_update_requirement( $requirement_id, $requirement ) {

    if( isset( $requirement['trigger_type'] )
        && $requirement['trigger_type'] === 'gamipress_cf_specific_new_form_submission' ) {

        // Save the post category field
        update_post_meta( $requirement_id, '_gamipress_caldera_form', $requirement['caldera_form'] );

    }
}
add_action( 'gamipress_ajax_update_requirement', 'gamipress_cf_ajax_update_requirement', 10, 2 );