<?php
/**
 * Triggers
 *
 * @package GamiPress\Caldera_Forms\Triggers
 * @since 1.0.0
 */

// Exit if accessed directly
if( !defined( 'ABSPATH' ) ) exit;

/**
 * Register Caldera Forms specific triggers
 *
 * @since 1.0.0
 *
 * @param array $triggers
 * @return mixed
 */
function gamipress_cf_activity_triggers( $triggers ) {

    $triggers[__( 'Caldera Forms', 'gamipress-caldera-forms-integration' )] = array(
        'gamipress_cf_new_form_submission' => __( 'Successful submit a form', 'gamipress-caldera-forms-integration' ),
        'gamipress_cf_specific_new_form_submission' => __( 'Successful submit a specific form', 'gamipress-caldera-forms-integration' ),
    );

    return $triggers;

}
add_filter( 'gamipress_activity_triggers', 'gamipress_cf_activity_triggers' );

/**
 * Build custom activity trigger label
 *
 * @since  1.0.0
 *
 * @param string    $title
 * @param integer   $requirement_id
 * @param array     $requirement
 *
 * @return string
 */
function gamipress_cf_activity_trigger_label( $title, $requirement_id, $requirement ) {

    switch( $requirement['trigger_type'] ) {
        case 'gamipress_cf_specific_new_form_submission':
            $form = Caldera_Forms::get_form( $requirement['caldera_form'] );

            if( is_array( $form ) && isset( $form['name'] ) ) {
                return sprintf( __( 'Submit %s', 'gamipress-caldera-forms-integration' ), $form['name'] );
            }
            break;
    }

    return $title;
}
add_filter( 'gamipress_activity_trigger_label', 'gamipress_cf_activity_trigger_label', 10, 3 );

/**
 * Register Caldera Forms specific activity triggers labels
 *
 * @since  1.0.0
 *
 * @param  array $specific_activity_trigger_labels
 * @return array
 */
function gamipress_cf_specific_activity_trigger_label( $specific_activity_trigger_labels ) {

    $specific_activity_trigger_labels['gamipress_cf_specific_new_form_submission'] = __( 'Submit %s', 'gamipress-caldera-forms-integration' );

    return $specific_activity_trigger_labels;
}
add_filter( 'gamipress_specific_activity_trigger_label', 'gamipress_cf_specific_activity_trigger_label' );

/**
 * Get user for a given trigger action.
 *
 * @since  1.0.0
 *
 * @param  integer $user_id user ID to override.
 * @param  string  $trigger Trigger name.
 * @param  array   $args    Passed trigger args.
 * @return integer          User ID.
 */
function gamipress_cf_trigger_get_user_id( $user_id, $trigger, $args ) {

    switch ( $trigger ) {
        case 'gamipress_cf_new_form_submission':
        case 'gamipress_cf_specific_new_form_submission':
            $user_id = $args[1];
            break;
    }

    return $user_id;

}
add_filter( 'gamipress_trigger_get_user_id', 'gamipress_cf_trigger_get_user_id', 10, 3);

/**
 * Extended meta data for event trigger logging
 *
 * @since 1.0.0
 *
 * @param array 	$log_meta
 * @param integer 	$user_id
 * @param string 	$trigger
 * @param integer 	$site_id
 * @param array 	$args
 *
 * @return array
 */
function gamipress_cf_log_event_trigger_meta_data( $log_meta, $user_id, $trigger, $site_id, $args ) {

    switch ( $trigger ) {
        case 'gamipress_cf_new_form_submission':
        case 'gamipress_cf_specific_new_form_submission':
            // Add the form ID
            $log_meta['form_id'] = $args[0];
            break;
    }

    return $log_meta;
}
add_filter( 'gamipress_log_event_trigger_meta_data', 'gamipress_cf_log_event_trigger_meta_data', 10, 5 );